Module: EffectiveLoggingHelper

Included in:
Effective::Datatables::Logs
Defined in:
app/helpers/effective_logging_helper.rb

Constant Summary collapse

ALLOWED_TAGS =
ActionView::Base.sanitized_allowed_tags.to_a + ['table', 'thead', 'tbody', 'tfoot', 'tr', 'td', 'th']
ALLOWED_ATTRIBUTES =
ActionView::Base.sanitized_allowed_attributes.to_a + ['colspan', 'rowspan']

Instance Method Summary collapse

Instance Method Details

#bootstrap_class_for_status(status) ⇒ Object



5
6
7
8
9
10
11
12
13
# File 'app/helpers/effective_logging_helper.rb', line 5

def bootstrap_class_for_status(status)
  case status
    when 'success'  ; 'success'
    when 'info'     ; 'info'
    when 'warning'  ; 'warning'
    when 'error'    ; 'danger'
    else 'primary'
  end
end

This is called on the Logs#show Admin page, and is intended for override by the application



51
52
53
54
55
56
57
58
59
60
61
# File 'app/helpers/effective_logging_helper.rb', line 51

def effective_logging_object_link_to(obj, action = :show)
  if obj.kind_of?(User)
    return (
      if action == :show && defined?(admin_user_path)
        link_to('View', admin_user_path(obj))
      elsif action == :edit && defined?(edit_admin_user_path)
        link_to('Edit', edit_admin_user_path(obj))
      end
    )
  end
end

#effective_logging_simple_format(value) ⇒ Object



94
95
96
# File 'app/helpers/effective_logging_helper.rb', line 94

def effective_logging_simple_format(value)
  simple_format(sanitize(value.to_s, :tags => ALLOWED_TAGS, :attributes => ALLOWED_ATTRIBUTES), {}, :sanitize => false)
end

#format_log_details_value(log, key) ⇒ Object



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'app/helpers/effective_logging_helper.rb', line 63

def format_log_details_value(log, key)
  value = log.details[key]

  if value.kind_of?(Hash)
    tableize_hash(value, :class => 'table', :style => 'width: 50%', :th => true)
  elsif value.kind_of?(Array)
    value.map { |value| effective_logging_simple_format(value) }.join.html_safe
  else
    value = value.to_s

    open = value.index('<!DOCTYPE html') || value.index('<html')
    close = value.rindex('</html>') if open.present?
    return effective_logging_simple_format(value) unless (open.present? && close.present?)

    before = value[0...open]
    after = value[(close+7)..-1]
    divide = before.sub!('<hr>', '').present?

    [
      h(before).gsub("\n", '<br>'),
      ((:hr) if divide),
      (:iframe, '',
        src: effective_logging.html_part_log_path(log, key: key),
        style: 'frameborder: 0; border: 0; width: 100%; height: 100%;',
        onload: "this.style.height=this.contentDocument.body.scrollHeight + 'px';",
        scrolling: 'no'),
      h(after).gsub("\n", '<br>')
    ].compact.join.html_safe
  end
end

#parents_of_log(log) ⇒ Object



19
20
21
22
23
# File 'app/helpers/effective_logging_helper.rb', line 19

def parents_of_log(log)
  parents = [log.parent]
  parents << parents.last.parent while(parents.last.try(:parent_id).present?)
  parents.compact.reverse
end

#render_log(log) ⇒ Object



15
16
17
# File 'app/helpers/effective_logging_helper.rb', line 15

def render_log(log)
  render(:partial => 'effective/logs/log', :locals => {:log => log})
end

#tableize_hash(hash, options = {}) ⇒ Object

Call me with :th => true, :sub_th => false Any other options are sent to the table tag



27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'app/helpers/effective_logging_helper.rb', line 27

def tableize_hash(hash, options = {})
  if hash.present? && hash.kind_of?(Hash)
    (:table, options) do
      hash.map do |k, v|
        (:tr) do
          ((options[:th] ? :th : :td), k) +
          (:td) do
            if v.kind_of?(Hash)
              tableize_hash(v, options.merge({:class => 'table table-bordered', :th => (options.key?(:sub_th) ? options[:sub_th] : options[:th])}))
            elsif v.kind_of?(Array)
              '[' + v.join(', ') + ']'
            else
              v.to_s
            end
          end
        end
      end.join('').html_safe
    end.html_safe
  else
    hash.to_s.html_safe
  end
end